@@ -102,7 +102,8 @@ def oauth2(
 
     try:
         user_data = client.get_user_data()
-    except Exception:
+    except Exception as exc:
+        messages.error(request, exc)
         messages.error(request, _("Error while fetching user data. Please try again."))
         return redirect("login")
 
